::: django_slack_tools.slack_messages.models
    options:
      show_root_heading: true

::: django_slack_tools.slack_messages.middlewares.django
    options:
      show_root_heading: true

::: django_slack_tools.slack_messages.message_templates.django
    options:
      show_root_heading: true

::: django_slack_tools.slack_messages.template_loaders.django
    options:
      show_root_heading: true
